@@ -13,6 +13,9 @@ mi_prepare_impute <- function(fo, data, maxit = 20) {
     search_term <- stringr::str_c("(^",DV,":)|(:",DV,":)|(:", DV, "$)|(^",DV,"$)")
     IVs <- fo_term_labels[!stringr::str_detect(fo_term_labels, search_term)]
     IVs <- paste0(IVs, collapse = " + ")
+    if (i > 1) {
+      IVs <- paste0(fo_vars[1], "+",  IVs)
+    }
     tmp_formula <- stats::as.formula(paste0(DV, " ~ " ,IVs))
     mi_formulas <- c(mi_formulas, tmp_formula)
   }
